@@ -117,6 +117,8 @@ class Export(ExportAbstract):
 @click.pass_context
 def export(ctx, file):
     """ exec export """
+    if ctx.obj == None:
+        account._noLoginMessage()
 
     if file == "":
         click.echo(" you need specify where the script is, command:\n")
@@ -127,16 +129,10 @@ def export(ctx, file):
         click.echo("  tla export --help")
         exit()
 
-    if ctx.obj == None:
-        account._noLoginMessage()
     try:
         scriptPath = os.path.split(file)[0]
         if scriptPath == "":
-            scriptPath = os.getcwd()
-
-        print(os.path.abspath('.'))
-        print(scriptPath)
-        exit()
+            scriptPath = os.path.abspath('.')
         sys.path.append(scriptPath)
         from export import Export
         ex = Export(ctx.obj)
